@@ -17,11 +17,11 @@
 
 package org.apache.eventmesh.common.protocol.tcp;
 
+import java.util.Objects;
+
 import lombok.Builder;
 import lombok.Data;
 
-import java.util.Objects;
-
 @Data
 @Builder
 public class UserAgent {
@@ -29,25 +29,23 @@ public class UserAgent {
     private String env;
     private String subsystem;
     private String path;
-    private int    pid;
+    private int pid;
     private String host;
-    private int    port;
+    private int port;
     private String version;
     private String username;
     private String password;
     private String idc;
-    private String producerGroup;
-    private String consumerGroup;
+    private String group;
     private String purpose;
     @Builder.Default
-    private int    unack = 0;
+    private int unack = 0;
 
     public UserAgent() {
     }
 
     public UserAgent(String env, String subsystem, String path, int pid, String host, int port, String version,
-                     String username, String password, String idc, String producerGroup, String consumerGroup,
-                     String purpose, int unack) {
+                     String username, String password, String idc, String group, String purpose, int unack) {
         this.env = env;
         this.subsystem = subsystem;
         this.path = path;
@@ -58,8 +56,7 @@ public class UserAgent {
         this.username = username;
         this.password = password;
         this.idc = idc;
-        this.producerGroup = producerGroup;
-        this.consumerGroup = consumerGroup;
+        this.group = group;
         this.purpose = purpose;
         this.unack = unack;
     }
@@ -67,34 +64,79 @@ public class UserAgent {
     @Override
     public String toString() {
         return String.format(
-            "UserAgent{env='%s', subsystem='%s', path='%s', pid=%d, host='%s', port=%d, version='%s', idc='%s', purpose='%s', unack='%d'}",
-            env, subsystem, path, pid, host, port, version, idc, purpose, unack);
+                "UserAgent{env='%s', subsystem='%s', group='%s', path='%s', pid=%d, host='%s',"
+                + " port=%d, version='%s', idc='%s', purpose='%s', unack='%d'}",
+                env, subsystem, group, path, pid, host, port, version, idc, purpose, unack);
     }
 
     @Override
     public boolean equals(Object o) {
-        if (this == o) return true;
-        if (o == null || getClass() != o.getClass()) return false;
+        if (this == o) {
+            return true;
+        }
+
+        if (o == null || getClass() != o.getClass()) {
+            return false;
+        }
 
         UserAgent userAgent = (UserAgent) o;
 
-        if (pid != userAgent.pid) return false;
-        if (port != userAgent.port) return false;
-        if (unack != userAgent.unack) return false;
-        if (!Objects.equals(subsystem, userAgent.subsystem)) return false;
-        if (!Objects.equals(path, userAgent.path)) return false;
-        if (!Objects.equals(host, userAgent.host)) return false;
-        if (!Objects.equals(purpose, userAgent.purpose)) return false;
-        if (!Objects.equals(version, userAgent.version)) return false;
-        if (!Objects.equals(username, userAgent.username)) return false;
-        if (!Objects.equals(password, userAgent.password)) return false;
-        if (!Objects.equals(env, userAgent.env)) return false;
+        if (pid != userAgent.pid) {
+            return false;
+        }
+
+        if (port != userAgent.port) {
+            return false;
+        }
+
+        if (unack != userAgent.unack) {
+            return false;
+        }
+
+        if (!Objects.equals(subsystem, userAgent.subsystem)) {
+            return false;
+        }
+
+        if (!Objects.equals(group, userAgent.group)) {
+            return false;
+        }
+
+
+        if (!Objects.equals(path, userAgent.path)) {
+            return false;
+        }
+
+        if (!Objects.equals(host, userAgent.host)) {
+            return false;
+        }
+
+        if (!Objects.equals(purpose, userAgent.purpose)) {
+            return false;
+        }
+
+        if (!Objects.equals(version, userAgent.version)) {
+            return false;
+        }
+
+        if (!Objects.equals(username, userAgent.username)) {
+            return false;
+        }
+
+        if (!Objects.equals(password, userAgent.password)) {
+            return false;
+        }
+
+        if (!Objects.equals(env, userAgent.env)) {
+            return false;
+        }
+
         return Objects.equals(idc, userAgent.idc);
     }
 
     @Override
     public int hashCode() {
         int result = subsystem != null ? subsystem.hashCode() : 0;
+        result = 31 * result + (group != null ? group.hashCode() : 0);
         result = 31 * result + (path != null ? path.hashCode() : 0);
         result = 31 * result + pid;
         result = 31 * result + (host != null ? host.hashCode() : 0);
