@@ -58,9 +58,9 @@ public class Codec {
     private static final byte[] VERSION = serializeBytes("0000");
 
     // todo: move to constants
-    public static String CLOUD_EVENTS_PROTOCOL_NAME = "cloudevents";
-    public static String EM_MESSAGE_PROTOCOL_NAME = "eventmeshmessage";
-    public static String OPEN_MESSAGE_PROTOCOL_NAME = "openmessage";
+    public static final String CLOUD_EVENTS_PROTOCOL_NAME = "cloudevents";
+    public static final String EM_MESSAGE_PROTOCOL_NAME = "eventmeshmessage";
+    public static final String OPEN_MESSAGE_PROTOCOL_NAME = "openmessage";
 
     // todo: use json util
     private static ObjectMapper OBJECT_MAPPER;
