@@ -24,6 +24,10 @@ public class EventMeshUnRegisterInfo {
     private String eventMeshClusterName;
     private String eventMeshName;
 
+    private String endPoint;
+
+    private String protocolType;
+
     public String getEventMeshClusterName() {
         return eventMeshClusterName;
     }
@@ -39,4 +43,20 @@ public class EventMeshUnRegisterInfo {
     public void setEventMeshName(String eventMeshName) {
         this.eventMeshName = eventMeshName;
     }
+
+    public String getEndPoint() {
+        return endPoint;
+    }
+
+    public void setEndPoint(String endPoint) {
+        this.endPoint = endPoint;
+    }
+
+    public String getProtocolType() {
+        return protocolType;
+    }
+
+    public void setProtocolType(String protocolType) {
+        this.protocolType = protocolType;
+    }
 }
