@@ -31,6 +31,7 @@ import org.apache.eventmesh.runtime.common.Pair;
 import org.apache.eventmesh.runtime.configuration.EventMeshHTTPConfiguration;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
 import org.apache.eventmesh.runtime.core.protocol.http.async.AsyncContext;
+import org.apache.eventmesh.runtime.core.protocol.http.processor.HandlerService;
 import org.apache.eventmesh.runtime.core.protocol.http.processor.inf.EventProcessor;
 import org.apache.eventmesh.runtime.core.protocol.http.processor.inf.HttpRequestProcessor;
 import org.apache.eventmesh.runtime.metrics.http.HTTPMetricsServer;
@@ -47,6 +48,7 @@ import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
+import java.util.Objects;
 import java.util.concurrent.RejectedExecutionException;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.atomic.AtomicBoolean;
@@ -63,10 +65,10 @@ import io.netty.channel.ChannelDuplexHandler;
 import io.netty.channel.ChannelFuture;
 import io.netty.channel.ChannelFutureListener;
 import io.netty.channel.ChannelHandlerContext;
+import io.netty.channel.ChannelInboundHandlerAdapter;
 import io.netty.channel.ChannelInitializer;
 import io.netty.channel.ChannelOption;
 import io.netty.channel.ChannelPipeline;
-import io.netty.channel.SimpleChannelInboundHandler;
 import io.netty.channel.socket.SocketChannel;
 import io.netty.channel.socket.nio.NioServerSocketChannel;
 import io.netty.handler.codec.http.DefaultFullHttpResponse;
@@ -91,6 +93,7 @@ import io.netty.handler.codec.http.multipart.InterfaceHttpData;
 import io.netty.handler.ssl.SslHandler;
 import io.netty.handler.timeout.IdleState;
 import io.netty.handler.timeout.IdleStateEvent;
+import io.netty.util.ReferenceCountUtil;
 import io.opentelemetry.api.trace.Span;
 import io.opentelemetry.semconv.trace.attributes.SemanticAttributes;
 
@@ -103,6 +106,8 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
 
     public Logger httpLogger = LoggerFactory.getLogger("http");
 
+    protected HandlerService handlerService;
+
     public HTTPMetricsServer metrics;
 
     public DefaultHttpDataFactory defaultHttpDataFactory = new DefaultHttpDataFactory(false);
@@ -296,49 +301,22 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
         return httpRequestBody;
     }
 
-    class HTTPHandler extends SimpleChannelInboundHandler<HttpRequest> {
+    class HTTPHandler extends ChannelInboundHandlerAdapter {
 
         @Override
-        protected void channelRead0(ChannelHandlerContext ctx, HttpRequest httpRequest) {
-            //            Context context = null;
-            //            Span span = null;
-            //            if (useTrace) {
-            //
-            //                //if the client injected span context,this will extract the context from httpRequest or it will be null
-            //                context = textMapPropagator.extract(Context.current(), httpRequest, new TextMapGetter<HttpRequest>() {
-            //                    @Override
-            //                    public Iterable<String> keys(HttpRequest carrier) {
-            //                        return carrier.headers().names();
-            //                    }
-            //
-            //                    @Override
-            //                    public String get(HttpRequest carrier, String key) {
-            //                        return carrier.headers().get(key);
-            //                    }
-            //                });
-            //
-            //                span = tracer.spanBuilder("HTTP " + httpRequest.method())
-            //                        .setParent(context)
-            //                        .setSpanKind(SpanKind.SERVER)
-            //                        .startSpan();
-            //                //attach the span to the server context
-            //                context = context.with(SpanKey.SERVER_KEY, span);
-            //                //put the context in channel
-            //                ctx.channel().attr(AttributeKeys.SERVER_CONTEXT).set(context);
-            //            }
+        public void channelRead(ChannelHandlerContext ctx, Object message) {
 
-
-
-            Span span = null;
-            //            Context context = null;
-            //            context = EventMeshServer.getTrace().extractFrom();
-            //            span = EventMeshServer.getTrace().createSpan("", context);
-            //            //attach the span to the server context
-            //            context = context.with(SpanKey.SERVER_KEY, span);
-            //            //put the context in channel
-            //            ctx.channel().attr(AttributeKeys.SERVER_CONTEXT).set(context);
+            HttpRequest httpRequest = (HttpRequest) message;
+            if (Objects.nonNull(handlerService) && handlerService.isProcessorWrapper(httpRequest)) {
+                handlerService.handler(ctx, httpRequest, asyncContextCompleteHandler);
+                return;
+            }
 
             try {
+
+                Span span = null;
+
+
                 preProcessHttpRequestHeader(ctx, httpRequest);
 
                 final Map<String, Object> headerMap = parseHttpHeader(httpRequest);
@@ -387,12 +365,6 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
                     requestCommand.setHttpVersion(httpRequest.protocolVersion().protocolName());
                     requestCommand.setRequestCode(requestCode);
 
-                    //                if (useTrace) {
-                    //                    span.setAttribute(SemanticAttributes.HTTP_METHOD, httpRequest.method().name());
-                    //                    span.setAttribute(SemanticAttributes.HTTP_FLAVOR, httpRequest.protocolVersion().protocolName());
-                    //                    span.setAttribute(String.valueOf(SemanticAttributes.HTTP_STATUS_CODE), requestCode);
-                    //                }
-
                     HttpCommand responseCommand = null;
 
                     if (StringUtils.isBlank(requestCode)
@@ -430,7 +402,9 @@ public abstract class AbstractHTTPServer extends AbstractRemotingServer {
 
 
             } catch (Exception ex) {
-                httpServerLogger.error("AbrstractHTTPServer.HTTPHandler.channelRead0 err", ex);
+                httpServerLogger.error("AbrstractHTTPServer.HTTPHandler.channelRead err", ex);
+            } finally {
+                ReferenceCountUtil.release(message);
             }
         }
 
