@@ -39,6 +39,7 @@ import org.apache.eventmesh.runtime.core.protocol.tcp.client.session.retry.Event
 import org.apache.eventmesh.runtime.metrics.tcp.EventMeshTcpMonitor;
 import org.apache.eventmesh.runtime.registry.Registry;
 import org.apache.eventmesh.runtime.util.EventMeshThreadFactoryImpl;
+import org.apache.eventmesh.webhook.admin.AdminWebHookConfigOperationManage;
 
 import java.util.List;
 import java.util.Optional;
@@ -208,7 +209,13 @@ public class EventMeshTCPServer extends AbstractRemotingServer {
 
         globalTrafficShapingHandler = newGTSHandler();
 
+        
+        AdminWebHookConfigOperationManage adminWebHookConfigOperationManage = new AdminWebHookConfigOperationManage();
+        adminWebHookConfigOperationManage.setConfigurationWrapper(eventMeshTCPConfiguration.getConfigurationWrapper());
+        adminWebHookConfigOperationManage.init();
+        
         clientManageController = new ClientManageController(this);
+        clientManageController.setAdminWebHookConfigOperationManage(adminWebHookConfigOperationManage);
 
         clientSessionGroupMapping = new ClientSessionGroupMapping(this);
         clientSessionGroupMapping.init();
@@ -264,7 +271,6 @@ public class EventMeshTCPServer extends AbstractRemotingServer {
             eventMeshRebalanceService.shutdown();
 
             this.unRegister();
-            registry.shutdown();
         }
 
         clientSessionGroupMapping.shutdown();
