@@ -17,7 +17,6 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.processor;
 
-import org.apache.eventmesh.common.utils.IPUtils;
 import org.apache.eventmesh.common.protocol.http.HttpCommand;
 import org.apache.eventmesh.common.protocol.http.body.client.UnSubscribeRequestBody;
 import org.apache.eventmesh.common.protocol.http.body.client.UnSubscribeResponseBody;
@@ -25,6 +24,7 @@ import org.apache.eventmesh.common.protocol.http.common.EventMeshRetCode;
 import org.apache.eventmesh.common.protocol.http.common.RequestCode;
 import org.apache.eventmesh.common.protocol.http.header.client.UnSubscribeRequestHeader;
 import org.apache.eventmesh.common.protocol.http.header.client.UnSubscribeResponseHeader;
+import org.apache.eventmesh.common.utils.IPUtils;
 import org.apache.eventmesh.common.utils.JsonUtils;
 import org.apache.eventmesh.runtime.boot.EventMeshHTTPServer;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
@@ -66,49 +66,49 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
 
     @Override
     public void processRequest(ChannelHandlerContext ctx, AsyncContext<HttpCommand> asyncContext)
-        throws Exception {
+            throws Exception {
         HttpCommand responseEventMeshCommand;
         httpLogger.info("cmd={}|{}|client2eventMesh|from={}|to={}",
-            RequestCode.get(Integer.valueOf(asyncContext.getRequest().getRequestCode())),
-            EventMeshConstants.PROTOCOL_HTTP,
-            RemotingHelper.parseChannelRemoteAddr(ctx.channel()), IPUtils.getLocalAddress());
+                RequestCode.get(Integer.valueOf(asyncContext.getRequest().getRequestCode())),
+                EventMeshConstants.PROTOCOL_HTTP,
+                RemotingHelper.parseChannelRemoteAddr(ctx.channel()), IPUtils.getLocalAddress());
         UnSubscribeRequestHeader unSubscribeRequestHeader =
-            (UnSubscribeRequestHeader) asyncContext.getRequest().getHeader();
+                (UnSubscribeRequestHeader) asyncContext.getRequest().getHeader();
         UnSubscribeRequestBody unSubscribeRequestBody =
-            (UnSubscribeRequestBody) asyncContext.getRequest().getBody();
+                (UnSubscribeRequestBody) asyncContext.getRequest().getBody();
 
         UnSubscribeResponseHeader unSubscribeResponseHeader =
-            UnSubscribeResponseHeader
-                .buildHeader(Integer.valueOf(asyncContext.getRequest().getRequestCode()),
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster,
-                    IPUtils.getLocalAddress(),
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEnv,
-                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
+                UnSubscribeResponseHeader
+                        .buildHeader(Integer.valueOf(asyncContext.getRequest().getRequestCode()),
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshCluster,
+                                IPUtils.getLocalAddress(),
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshEnv,
+                                eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshIDC);
 
         //validate header
         if (StringUtils.isBlank(unSubscribeRequestHeader.getIdc())
-            || StringUtils.isBlank(unSubscribeRequestHeader.getPid())
-            || !StringUtils.isNumeric(unSubscribeRequestHeader.getPid())
-            || StringUtils.isBlank(unSubscribeRequestHeader.getSys())) {
+                || StringUtils.isBlank(unSubscribeRequestHeader.getPid())
+                || !StringUtils.isNumeric(unSubscribeRequestHeader.getPid())
+                || StringUtils.isBlank(unSubscribeRequestHeader.getSys())) {
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                unSubscribeResponseHeader,
-                UnSubscribeResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
+                    unSubscribeResponseHeader,
+                    UnSubscribeResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PROTOCOL_HEADER_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
 
         //validate body
         if (StringUtils.isBlank(unSubscribeRequestBody.getUrl())
-            || CollectionUtils.isEmpty(unSubscribeRequestBody.getTopics())
-            || StringUtils.isBlank(unSubscribeRequestBody.getConsumerGroup())) {
+                || CollectionUtils.isEmpty(unSubscribeRequestBody.getTopics())
+                || StringUtils.isBlank(unSubscribeRequestBody.getConsumerGroup())) {
 
             responseEventMeshCommand = asyncContext.getRequest().createHttpCommandResponse(
-                unSubscribeResponseHeader,
-                UnSubscribeResponseBody
-                    .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getRetCode(),
-                        EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getErrMsg()));
+                    unSubscribeResponseHeader,
+                    UnSubscribeResponseBody
+                            .buildBody(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getRetCode(),
+                                    EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR.getErrMsg()));
             asyncContext.onComplete(responseEventMeshCommand);
             return;
         }
@@ -129,8 +129,8 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
                         httpLogger.debug("{}", httpCommand);
                     }
                     eventMeshHTTPServer.sendResponse(ctx, httpCommand.httpResponse());
-                    eventMeshHTTPServer.metrics.summaryMetrics.recordHTTPReqResTimeCost(
-                        System.currentTimeMillis() - asyncContext.getRequest().getReqTime());
+                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordHTTPReqResTimeCost(
+                            System.currentTimeMillis() - asyncContext.getRequest().getReqTime());
                 } catch (Exception ex) {
                     // ignore
                 }
@@ -144,12 +144,12 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
 
             for (String unSubTopic : unSubTopicList) {
                 List<Client> groupTopicClients = eventMeshHTTPServer.localClientInfoMapping
-                    .get(consumerGroup + "@" + unSubTopic);
+                        .get(consumerGroup + "@" + unSubTopic);
                 Iterator<Client> clientIterator = groupTopicClients.iterator();
                 while (clientIterator.hasNext()) {
                     Client client = clientIterator.next();
                     if (StringUtils.equals(client.pid, pid)
-                        && StringUtils.equals(client.url, unSubscribeUrl)) {
+                            && StringUtils.equals(client.url, unSubscribeUrl)) {
                         httpLogger.warn("client {} start unsubscribe", JsonUtils.serialize(client));
                         clientIterator.remove();
                     }
@@ -164,7 +164,7 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
                             clientUrls.add(client.url);
                             if (idcUrls.containsKey(client.idc)) {
                                 idcUrls.get(client.idc)
-                                    .add(StringUtils.deleteWhitespace(client.url));
+                                        .add(StringUtils.deleteWhitespace(client.url));
                             } else {
                                 List<String> urls = new ArrayList<>();
                                 urls.add(client.url);
@@ -175,18 +175,18 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
                     }
                     synchronized (eventMeshHTTPServer.localConsumerGroupMapping) {
                         ConsumerGroupConf consumerGroupConf =
-                            eventMeshHTTPServer.localConsumerGroupMapping.get(consumerGroup);
+                                eventMeshHTTPServer.localConsumerGroupMapping.get(consumerGroup);
                         Map<String, ConsumerGroupTopicConf> map =
-                            consumerGroupConf.getConsumerGroupTopicConf();
+                                consumerGroupConf.getConsumerGroupTopicConf();
                         for (String topicKey : map.keySet()) {
                             // only modify the topic to subscribe
                             if (StringUtils.equals(unSubTopic, topicKey)) {
                                 ConsumerGroupTopicConf latestTopicConf =
-                                    new ConsumerGroupTopicConf();
+                                        new ConsumerGroupTopicConf();
                                 latestTopicConf.setConsumerGroup(consumerGroup);
                                 latestTopicConf.setTopic(unSubTopic);
                                 latestTopicConf
-                                    .setSubscriptionItem(map.get(topicKey).getSubscriptionItem());
+                                        .setSubscriptionItem(map.get(topicKey).getSubscriptionItem());
                                 latestTopicConf.setUrls(clientUrls);
 
                                 latestTopicConf.setIdcUrls(idcUrls);
@@ -195,7 +195,7 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
                             }
                         }
                         eventMeshHTTPServer.localConsumerGroupMapping
-                            .put(consumerGroup, consumerGroupConf);
+                                .put(consumerGroup, consumerGroupConf);
                     }
                 } else {
                     isChange = false;
@@ -206,61 +206,60 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
             if (isChange) {
                 try {
                     eventMeshHTTPServer.getConsumerManager().notifyConsumerManager(consumerGroup,
-                        eventMeshHTTPServer.localConsumerGroupMapping.get(consumerGroup));
+                            eventMeshHTTPServer.localConsumerGroupMapping.get(consumerGroup));
 
                     responseEventMeshCommand =
-                        asyncContext.getRequest().createHttpCommandResponse(EventMeshRetCode.SUCCESS);
+                            asyncContext.getRequest().createHttpCommandResponse(EventMeshRetCode.SUCCESS);
                     asyncContext.onComplete(responseEventMeshCommand, handler);
 
                 } catch (Exception e) {
                     HttpCommand err = asyncContext.getRequest().createHttpCommandResponse(
-                        unSubscribeResponseHeader,
-                        UnSubscribeResponseBody
-                            .buildBody(EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getRetCode(),
-                                EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getErrMsg()
-                                    + EventMeshUtil.stackTrace(e, 2)));
+                            unSubscribeResponseHeader,
+                            UnSubscribeResponseBody
+                                    .buildBody(EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getRetCode(),
+                                            EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getErrMsg()
+                                                    + EventMeshUtil.stackTrace(e, 2)));
                     asyncContext.onComplete(err);
                     long endTime = System.currentTimeMillis();
                     httpLogger.error(
-                        "message|eventMesh2mq|REQ|ASYNC|send2MQCost={}ms"
-                            + "|topic={}|bizSeqNo={}|uniqueId={}", endTime - startTime,
-                        JsonUtils.serialize(unSubscribeRequestBody.getTopics()),
-                        unSubscribeRequestBody.getUrl(), e);
-                    eventMeshHTTPServer.metrics.summaryMetrics.recordSendMsgFailed();
-                    eventMeshHTTPServer.metrics.summaryMetrics
-                        .recordSendMsgCost(endTime - startTime);
+                            "message|eventMesh2mq|REQ|ASYNC|send2MQCost={}ms"
+                                    + "|topic={}|bizSeqNo={}|uniqueId={}", endTime - startTime,
+                            JsonUtils.serialize(unSubscribeRequestBody.getTopics()),
+                            unSubscribeRequestBody.getUrl(), e);
+                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsgFailed();
+                    eventMeshHTTPServer.metrics.getSummaryMetrics()
+                            .recordSendMsgCost(endTime - startTime);
                 }
             } else {
                 //remove
                 try {
                     eventMeshHTTPServer.getConsumerManager()
-                        .notifyConsumerManager(consumerGroup, null);
+                            .notifyConsumerManager(consumerGroup, null);
                     responseEventMeshCommand =
-                        asyncContext.getRequest().createHttpCommandResponse(EventMeshRetCode.SUCCESS);
+                            asyncContext.getRequest().createHttpCommandResponse(EventMeshRetCode.SUCCESS);
                     asyncContext.onComplete(responseEventMeshCommand, handler);
                     // clean ClientInfo
                     eventMeshHTTPServer.localClientInfoMapping.keySet()
-                        .removeIf(s -> StringUtils.contains(s, consumerGroup));
+                            .removeIf(s -> StringUtils.contains(s, consumerGroup));
                     // clean ConsumerGroupInfo
                     eventMeshHTTPServer.localConsumerGroupMapping.keySet()
-                        .removeIf(s -> StringUtils.equals(consumerGroup, s));
+                            .removeIf(s -> StringUtils.equals(consumerGroup, s));
                 } catch (Exception e) {
                     HttpCommand err = asyncContext.getRequest().createHttpCommandResponse(
-                        unSubscribeResponseHeader,
-                        UnSubscribeResponseBody
-                            .buildBody(EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getRetCode(),
-                                EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getErrMsg()
-                                    + EventMeshUtil.stackTrace(e, 2)));
+                            unSubscribeResponseHeader,
+                            UnSubscribeResponseBody
+                                    .buildBody(EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getRetCode(),
+                                            EventMeshRetCode.EVENTMESH_UNSUBSCRIBE_ERR.getErrMsg()
+                                                    + EventMeshUtil.stackTrace(e, 2)));
                     asyncContext.onComplete(err);
                     long endTime = System.currentTimeMillis();
                     httpLogger.error(
-                        "message|eventMesh2mq|REQ|ASYNC|send2MQCost={}ms"
-                            + "|topic={}|bizSeqNo={}|uniqueId={}", endTime - startTime,
-                        JsonUtils.serialize(unSubscribeRequestBody.getTopics()),
-                        unSubscribeRequestBody.getUrl(), e);
-                    eventMeshHTTPServer.metrics.summaryMetrics.recordSendMsgFailed();
-                    eventMeshHTTPServer.metrics.summaryMetrics
-                        .recordSendMsgCost(endTime - startTime);
+                            "message|eventMesh2mq|REQ|ASYNC|send2MQCost={}ms"
+                                    + "|topic={}|bizSeqNo={}|uniqueId={}", endTime - startTime,
+                            JsonUtils.serialize(unSubscribeRequestBody.getTopics()),
+                            unSubscribeRequestBody.getUrl(), e);
+                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsgFailed();
+                    eventMeshHTTPServer.metrics.getSummaryMetrics().recordSendMsgCost(endTime - startTime);
                 }
             }
         }
@@ -289,7 +288,7 @@ public class UnSubscribeProcessor implements HttpRequestProcessor {
             String groupTopicKey = client.consumerGroup + "@" + client.topic;
             if (eventMeshHTTPServer.localClientInfoMapping.containsKey(groupTopicKey)) {
                 List<Client> localClients =
-                    eventMeshHTTPServer.localClientInfoMapping.get(groupTopicKey);
+                        eventMeshHTTPServer.localClientInfoMapping.get(groupTopicKey);
                 boolean isContains = false;
                 for (Client localClient : localClients) {
                     if (StringUtils.equals(localClient.url, client.url)) {
