@@ -17,6 +17,8 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.retry;
 
+import org.apache.eventmesh.runtime.boot.EventMeshHTTPServer;
+
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.DelayQueue;
 import java.util.concurrent.ThreadFactory;
@@ -24,7 +26,6 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import org.apache.eventmesh.runtime.boot.EventMeshHTTPServer;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -40,7 +41,7 @@ public class HttpRetryer {
         this.eventMeshHTTPServer = eventMeshHTTPServer;
     }
 
-    private DelayQueue<DelayRetryable> failed = new DelayQueue<DelayRetryable>();
+    private DelayQueue<DelayRetryable> failed = new DelayQueue<>();
 
     private ThreadPoolExecutor pool;
 
@@ -58,7 +59,8 @@ public class HttpRetryer {
         pool = new ThreadPoolExecutor(eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerRetryThreadNum,
                 eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerRetryThreadNum,
                 60000,
-                TimeUnit.MILLISECONDS, new ArrayBlockingQueue<Runnable>(eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerRetryBlockQSize),
+                TimeUnit.MILLISECONDS, new ArrayBlockingQueue<>(
+                    eventMeshHTTPServer.getEventMeshHttpConfiguration().eventMeshServerRetryBlockQSize),
                 new ThreadFactory() {
                     private AtomicInteger count = new AtomicInteger();
 
@@ -69,29 +71,27 @@ public class HttpRetryer {
                         thread.setDaemon(true);
                         return thread;
                     }
-                }, new ThreadPoolExecutor.AbortPolicy());
+                },
+                new ThreadPoolExecutor.AbortPolicy());
 
-        dispatcher = new Thread(new Runnable() {
-            @Override
-            public void run() {
-                try {
-                    DelayRetryable retryObj = null;
-                    while (!Thread.currentThread().isInterrupted() && (retryObj = failed.take()) != null) {
-                        final DelayRetryable delayRetryable = retryObj;
-                        pool.execute(() -> {
-                            try {
-                                delayRetryable.retry();
-                                if (retryLogger.isDebugEnabled()) {
-                                    retryLogger.debug("retryObj : {}", delayRetryable);
-                                }
-                            } catch (Exception e) {
-                                retryLogger.error("http-retry-dispatcher error!", e);
+        dispatcher = new Thread(() -> {
+            try {
+                DelayRetryable retryObj;
+                while (!Thread.currentThread().isInterrupted() && (retryObj = failed.take()) != null) {
+                    final DelayRetryable delayRetryable = retryObj;
+                    pool.execute(() -> {
+                        try {
+                            delayRetryable.retry();
+                            if (retryLogger.isDebugEnabled()) {
+                                retryLogger.debug("retryObj : {}", delayRetryable);
                             }
-                        });
-                    }
-                } catch (Exception e) {
-                    retryLogger.error("http-retry-dispatcher error!", e);
+                        } catch (Exception e) {
+                            retryLogger.error("http-retry-dispatcher error!", e);
+                        }
+                    });
                 }
+            } catch (Exception e) {
+                retryLogger.error("http-retry-dispatcher error!", e);
             }
         }, "http-retry-dispatcher");
         dispatcher.setDaemon(true);
@@ -102,6 +102,13 @@ public class HttpRetryer {
         return failed.size();
     }
 
+    /**
+     * Get failed queue, this method is just used for metrics.
+     */
+    public DelayQueue<DelayRetryable> getFailedQueue() {
+        return failed;
+    }
+
     public void shutdown() {
         dispatcher.interrupt();
         pool.shutdown();
