@@ -19,6 +19,7 @@ package org.apache.eventmesh.client.http.producer;
 
 import org.apache.eventmesh.client.http.AbstractHttpClient;
 import org.apache.eventmesh.client.http.EventMeshRetObj;
+import org.apache.eventmesh.client.http.ProtocolConstant;
 import org.apache.eventmesh.client.http.conf.EventMeshHttpClientConfig;
 import org.apache.eventmesh.client.http.model.RequestParam;
 import org.apache.eventmesh.client.http.util.HttpUtils;
@@ -45,10 +46,6 @@ import lombok.extern.slf4j.Slf4j;
 @Slf4j
 class EventMeshMessageProducer extends AbstractHttpClient implements EventMeshProtocolProducer<EventMeshMessage> {
 
-    private static final String PROTOCOL_TYPE = "eventmeshmessage";
-
-    private static final String PROTOCOL_DESC = "http";
-
     public EventMeshMessageProducer(EventMeshHttpClientConfig eventMeshHttpClientConfig) throws EventMeshException {
         super(eventMeshHttpClientConfig);
     }
@@ -129,8 +126,8 @@ class EventMeshMessageProducer extends AbstractHttpClient implements EventMeshPr
                 .addHeader(ProtocolKey.ClientInstanceKey.USERNAME, eventMeshHttpClientConfig.getUserName())
                 .addHeader(ProtocolKey.ClientInstanceKey.PASSWD, eventMeshHttpClientConfig.getPassword())
                 .addHeader(ProtocolKey.VERSION, ProtocolVersion.V1.getVersion())
-                .addHeader(ProtocolKey.PROTOCOL_TYPE, PROTOCOL_TYPE)
-                .addHeader(ProtocolKey.PROTOCOL_DESC, PROTOCOL_DESC)
+                .addHeader(ProtocolKey.PROTOCOL_TYPE, ProtocolConstant.EM_MESSAGE_PROTOCOL)
+                .addHeader(ProtocolKey.PROTOCOL_DESC, ProtocolConstant.PROTOCOL_DESC)
                 //default ce version is 1.0
                 .addHeader(ProtocolKey.PROTOCOL_VERSION, SpecVersion.V1.toString())
                 .addHeader(ProtocolKey.LANGUAGE, Constants.LANGUAGE_JAVA)
